# TODO

- .env parser
- context managers
- config loaders
- version option
- Add extra types
    - int narg tuples
    - https://click.palletsprojects.com/en/8.1.x/options/#feature-switches
    - secret
- value prompting
- docs
- tests
- async runner
